@@ -194,7 +194,8 @@ class CheckTree(sw.LabeledWidget):
             The return from any command invoked by changing the state.
         """
         tags = [*self.tree.item(iid, "tags")]
-        tags.remove("checked")
+        if "checked" in tags:
+            tags.remove("checked")
         self.tree.item(iid, image=self.unchecked_image, tags=tags)
 
         # If this is a branch node, i.e. it has children, change them too
@@ -308,6 +309,20 @@ class CheckTree(sw.LabeledWidget):
         """
         return self.tree.get_children(item)
 
+    def get_leaves(self, item=None):
+        """Returns the iid values of all leaves of the tree belove of the item specified
+        by the item argument. If the argument is omitted, it gives the leaves for the
+        entire tree.
+        """
+        leaves = []
+        for child in self.tree.get_children(item):
+            children = self.tree.get_children(child)
+            if len(children) > 0:
+                leaves.extend(self.get_leaves(child))
+            else:
+                leaves.append(child)
+        return leaves
+
     def heading(self, cid, option=None, **kw):
         """Use this method to configure the column heading that appears at the top of
         the widget for the column specified by cid, which may be either a column index
@@ -547,6 +562,16 @@ class CheckTree(sw.LabeledWidget):
             for item in items:
                 self._select(item)
 
+    def selection_clear(self, items=None):
+        """Clear all selections from the subtree(s)"""
+        if items is None:
+            self.selection_remove("")
+        elif isinstance(items, str):
+            self.selection_remove(self.get(items))
+        else:
+            for item in items:
+                self.selection_remove(self.get(item))
+
     def selection_remove(self, items):
         """Unselect any items specified by the argument, which may be a single iid or a
         sequence of iids.
@@ -561,7 +586,7 @@ class CheckTree(sw.LabeledWidget):
         """Only the specified items will be selected; if any other items were selected
         before, they will become unselected.
         """
-        self.selection_remove(self.get_children())
+        self.selection_remove(self.get_leaves())
         self.selection_add(items)
 
     def selection_toggle(self, items):
